@@ -143,7 +143,8 @@ class WSTerminalServerHandler(tornado.websocket.WebSocketHandler):
             self._workspace = workspace.Workspace(workspace_path)
             data = self._workspace.snapshot()
             await self.send_response(
-                request, data=data,
+                request,
+                data=data,
             )
         elif self._workspace and request["command"] == proto.EnumCommand.WRITE_FILE:
             utils.logger.info(
@@ -295,7 +296,13 @@ class WSTerminalServerHandler(tornado.websocket.WebSocketHandler):
 
                 if self._shell:
                     if sys.platform == "win32":
-                        buffer = buffer.decode("gbk").encode("utf-8") # TODO: fixme
+                        try:
+                            buffer = buffer.decode("gbk").encode("utf-8")  # TODO: fixme
+                        except UnicodeDecodeError:
+                            utils.logger.warn(
+                                "[%s] Decode buffer %r failed"
+                                % (self.__class__.__name__, buffer)
+                            )
                     await self.write_shell_stdout(buffer)
         utils.logger.warn("[%s] Shell process exit" % self.__class__.__name__)
         if self._shell:
